@@ -447,7 +447,11 @@ func updateSealedSecretsStatusConditions(st *ssv1alpha1.SealedSecretStatus, unse
 
 	// Status has changed, update the transition time and signal that an update is required
 	if cond.Status != status {
-		cond.LastTransitionTime = cond.LastUpdateTime
+		if !cond.LastUpdateTime.IsZero() {
+			cond.LastTransitionTime = cond.LastUpdateTime
+		} else {
+			cond.LastTransitionTime = metav1.Now()
+		}
 		cond.Status = status
 		cond.LastUpdateTime = metav1.Now()
 		updateRequired = true
