@@ -17,9 +17,10 @@ import (
 )
 
 var (
-	listenAddr   = flag.String("listen-addr", ":8080", "HTTP serving address.")
-	readTimeout  = flag.Duration("read-timeout", 2*time.Minute, "HTTP request timeout.")
-	writeTimeout = flag.Duration("write-timeout", 2*time.Minute, "HTTP response timeout.")
+	listenAddr        = flag.String("listen-addr", ":8080", "HTTP serving address.")
+	listenMetricsAddr = flag.String("listen-metrics-addr", ":8081", "HTTP metrics serving address.")
+	readTimeout       = flag.Duration("read-timeout", 2*time.Minute, "HTTP request timeout.")
+	writeTimeout      = flag.Duration("write-timeout", 2*time.Minute, "HTTP response timeout.")
 )
 
 // Called on every request to /cert.  Errors will be logged and return a 500.
@@ -44,8 +45,6 @@ func httpserver(cp certProvider, sc secretChecker, sr secretRotator, burst int,
 		}
 	})
 
-	mux.Handle("/metrics", promhttp.Handler())
-
 	mux.Handle("/v1/verify", Instrument("/v1/verify", httpRateLimiter.RateLimit(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		content, err := io.ReadAll(r.Body)
 		if err != nil {
@@ -119,6 +118,26 @@ func httpserver(cp certProvider, sc secretChecker, sr secretRotator, burst int,
 	return &server
 }
 
+func httpserverMetrics() *http.Server {
+	mux := http.NewServeMux()
+	mux.Handle("/metrics", promhttp.Handler())
+
+	server := http.Server{
+		Addr:              *listenMetricsAddr,
+		Handler:           mux,
+		ReadTimeout:       *readTimeout,
+		ReadHeaderTimeout: *readTimeout,
+		WriteTimeout:      *writeTimeout,
+	}
+
+	log.Infof("HTTP metrics server serving on %s", server.Addr)
+	go func() {
+		err := server.ListenAndServe()
+		log.Errorf("HTTP metrics server exiting: %v", err)
+	}()
+	return &server
+}
+
 func rateLimiter(burst int, rate int) throttled.HTTPRateLimiter {
 	store, err := memstore.New(65536)
 	if err != nil {
